Opinion Type: | Release Month: | Release Day: |

All Per Curiam for July 2014

Case No. | View | Case Style | Note | Disposition | Disposition Date
--- | --- | --- | --- | --- | ---
12-2649 |  | Shawn Wuertley vs State of Florida |  | Affirmed | 07/07/2014
12-3121 |  | Tyrone D. Blackshear vs State of Florida |  | Affirmed | 07/22/2014
12-3767 |  | Timothy R. Williams vs State of Florida |  | Affirmed | 07/24/2014
12-5923 |  | Lavon Tony Butler vs State of Florida |  | Affirmed | 07/10/2014
13-0024 |  | Vandin Calitu and Adriana Proteasa-Calitu vs Chase Home Finance LLC |  | Affirmed | 07/24/2014
13-0406 |  | Michael Brown vs State of Florida |  | Affirmed | 07/16/2014
13-1123 |  | N'Kosi Lerone Jones vs State of Florida |  | Affirmed | 07/03/2014
13-1286 |  | Brendan Behan Horan vs State of Florida |  | Affirmed | 07/23/2014
13-1323 |  | Shervin Singleton vs State of Florida |  | Affirmed | 07/16/2014
13-1366 |  | Sean Fullwood vs State of Florida |  | Affirmed | 07/17/2014
13-1472 |  | Larry Lee Miller vs State of Florida |  | Affirmed | 07/10/2014
13-1481 |  | James McMillan, et al. vs Herbert Fischer and Betty Fischer |  | Affirmed | 07/16/2014
13-1530 |  | Henry Lee Roberson, Jr. vs State of Florida |  | Affirmed | 07/23/2014
13-1599 |  | Victor Jerome Bell vs State of Florida |  | Affirmed | 07/16/2014
13-1845 |  | Ryan Alan Welch vs State of Florida |  | Affirmed | 07/24/2014
13-1866 |  | Roger F. Homminga vs State of Florida |  | Denied | 07/16/2014
13-2057 |  | Lapolean Johnny Owens vs State of Florida |  | Affirmed | 07/17/2014
13-2153 |  | Shannon Abbott vs State of Florida |  | Affirmed | 07/17/2014
13-2359 |  | Brandon James Wheeler Wilder vs State of Florida |  | Affirmed | 07/10/2014
13-2386 |  | Christian H. F. Riley, Former Husband vs Sara B. Riley, n/k/a Sara B. Dipaolo etc. |  | Affirmed | 07/23/2014
13-2507 |  | Johnny C Jones vs State of Florida |  | Affirmed | 07/17/2014
13-2532 |  | Renardo Antione Smith vs State of Florida |  | Affirmed | 07/14/2014
13-2596 |  | Phillip W. Moore vs State of Florida |  | Affirmed | 07/22/2014
13-2835 |  | Robert D. Kennedy vs State of Florida |  | Affirmed | 07/08/2014
13-2836 |  | Nicole Renee Henderson vs State of Florida |  | Affirmed | 07/07/2014
13-2981 |  | Ulisban Shawn Bryant vs State of Florida |  | Affirmed | 07/24/2014
13-2988 |  | Andre Lanier Cook vs State of Florida |  | Affirmed | 07/02/2014
13-3102 |  | Andrae Hicks vs State of Florida |  | Affirmed | 07/03/2014
13-3468 |  | Derrick Antonio Brown vs State of Florida |  | Affirmed | 07/03/2014
13-3479 |  | Larry Darnell Blocker vs State of Florida |  | Affirmed | 07/16/2014
13-3504 |  | Gregory L. Taylor vs State of Florida |  | Affirmed | 07/24/2014
13-3505 |  | Christopher Jonas vs State of Florida |  | Affirmed | 07/07/2014
13-3550 |  | Royce Mincey vs State of Florida |  | Affirmed | 07/02/2014
13-3555 |  | Jeremiah Taylor vs State of Florida |  | Affirmed | 07/07/2014
13-3569 |  | Anthony Cortes Dees vs State of Florida |  | Affirmed | 07/21/2014
13-3595 |  | William E. Fisher, Jr. vs John W. Allen and Roxie Allen |  | Affirmed | 07/23/2014
13-3693 |  | Samuel Edward Stephens, II vs State of Florida |  | Affirmed | 07/21/2014
13-3751 |  | Karren Trappio Plaines vs State of Florida |  | Affirmed | 07/16/2014
13-3831 |  | Michael Reid vs State of Florida |  | Affirmed | 07/09/2014
13-3850 |  | Muhammad Morris vs State of Florida |  | Affirmed | 07/16/2014
13-3863 |  | Stephen A. Scott, P.A. and Stephen A. Scott vs City of Gainesville, Florida |  | Affirmed | 07/16/2014
13-4004 |  | Christian H. F. Riley, Former Husband vs Sara B. Riley, n/k/a Sara B. Dipaolo, Former Wife |  | Affirmed | 07/23/2014
13-4056 |  | Antonio Emmanuel Moorer vs State of Florida |  | Affirmed | 07/07/2014
13-4130 |  | Alfonso Dewayne Griffin vs State of Florida |  | Affirmed | 07/08/2014
13-4235 |  | Michael Welch vs State of Florida |  | Affirmed | 07/21/2014
13-4339 |  | Darrell Shanta Jenkins vs State of Florida |  | Affirmed | 07/09/2014
13-4363 |  | Dequian Demorral Watson vs State of Florida |  | Affirmed | 07/03/2014
13-4391 |  | Lawton Calvin Adkins vs State of Florida |  | Affirmed | 07/07/2014
13-4396 |  | SHAWN TREVOR BURBANK vs Diana Lynn Hopkins |  | Affirmed | 07/22/2014
13-4474 |  | Florida Transportation Engineering, et al. vs Kenneth Bennett, Jr. |  | Affirmed | 07/11/2014
13-4504 |  | Joseph Miller vs State of Florida |  | Affirmed | 07/23/2014
13-4575 |  | Anthony Jerome Fields vs State of Florida |  | Affirmed | 07/07/2014
13-4582 |  | Dequian Demorral Watson vs State of Florida |  | Affirmed | 07/07/2014
13-4583 |  | Eric Engreen Green vs State of Florida |  | Affirmed | 07/17/2014
13-4688 |  | Bernard C. McGee vs Michael D. Crews, Sec., Florida Dept., etc. |  | Affirmed | 07/23/2014
13-4707 |  | Marcus Demetrius Bullock vs State of Florida |  | Affirmed | 07/03/2014
13-4806 |  | Jason D. Kirk vs State of Florida |  | Affirmed | 07/17/2014
13-4863 |  | Kenneth Bennett, Jr. vs Florida Transportation Engineering, et al. |  | Affirmed | 07/11/2014
13-4873 |  | Adria L. Williams, Former Wife vs David E. Radford, Former Husband |  | Affirmed | 07/21/2014
13-4914 |  | Tracey Dewrell vs Tom Dewrell, Individually and as the etc. |  | Affirmed | 07/16/2014
13-4960 |  | Southern Baptist Hospital of Florida, Inc., etc. vs Diane L. Smith, as Personal etc et al. |  | Dismissed | 07/17/2014
13-4967 |  | Christine C. Whitney vs Wells Fargo Bank, N.A. |  | Affirmed | 07/07/2014
13-4985 |  | Alfonso Dewayne Griffin vs State of Florida |  | Affirmed | 07/08/2014
13-5016 |  | Ronald E. Downs, Jr. vs State of Florida |  | Denied | 07/03/2014
13-5017 |  | Willie George Byrd vs State of Florida |  | Affirmed | 07/02/2014
13-5041 |  | Vernon Stewart Polk vs State of Florida |  | Affirmed | 07/23/2014
13-5044 |  | Terra Mar Property Management, LLC vs The Bank of New York Mellon etc. |  | Affirmed | 07/11/2014
13-5176 |  | Jose Luis Del Toro vs Michael D. Crews, Secretary, etc. |  | Affirmed | 07/10/2014
13-5222 |  | Jason Wayne Springer vs Florida Department of Corrections |  | Denied | 07/14/2014
13-5240 |  | Samantha Grover vs Bradford County Sheriff's Office |  | Affirmed | 07/14/2014
13-5266 |  | William H. Carr, Jr., Husband vs Lynne O'Shall Carr, Wife |  | Affirmed | 07/17/2014
13-5364 |  | Edwin D. Morris vs Dept. of Corrections |  | Denied | 07/11/2014
13-5426 |  | Johnny L. Brown vs Florida Parole Commission |  | Denied | 07/02/2014
13-5431 |  | Vernterio Tremell Jenkins vs State of Florida |  | Affirmed | 07/10/2014
13-5437 |  | Cabana Beach Club, LLC's vs Key Bank National Association, etc. et al. |  | Affirmed | 07/07/2014
13-5445 |  | Dewey Kessler vs Stage Call, Inc. And Travelers etc. |  | Affirmed | 07/21/2014
13-5448 |  | Victor Parker vs State of Florida |  | Affirmed | 07/16/2014
13-5532 |  | Marianne Armstrong vs State of Florida |  | Affirmed | 07/11/2014
13-5624 |  | Michael Edward Johnson vs Secretary, Department of Corr. |  | Denied | 07/14/2014
13-5629 |  | Demond Williams vs State of Florida |  | Affirmed | 07/02/2014
13-5634 |  | Maribeth S. Gaffney vs State of Florida |  | Affirmed | 07/02/2014
13-5650 |  | Samuel Staten vs State of Florida |  | Affirmed | 07/02/2014
13-5660 |  | Octavious Johnson vs Keefe Commissary Network, Florida Dept. of Corr. |  | Affirmed | 07/16/2014
13-5693 |  | Tony Dupree, etc. vs Florida Department of Corrections |  | Denied | 07/11/2014
13-5781 |  | Rodney McCutcheon vs Michael D. Crews, Sec., Department of Corrections |  | Denied | 07/17/2014
13-5789 |  | Ramon Castro vs City of Fort Pierce and Florida, etc., et al |  | Affirmed | 07/24/2014
13-5864 |  | Christopher G. Walker vs Michael D. Crews, Sec., Florida Dept., etc. |  | Denied | 07/23/2014
13-5910 |  | Joseph C. Thompson vs State of Florida |  | Denied | 07/16/2014
13-6037 |  | Otix Blaxton vs Florida Department of Corrections |  | Denied | 07/09/2014
13-6063 |  | Ramon Del Orbe vs Reemployment Assistance Appeals Commission et al. |  | Affirmed | 07/24/2014
13-6069 |  | Stephen Lewis Furney, III vs State of Florida |  | Affirmed | 07/17/2014
13-6113 |  | Michael E. Goggins vs Department of Corrections |  | Denied | 07/17/2014
13-6114 |  | Alonzie Wiggins vs Fla. Dept. of Corrections |  | Denied | 07/03/2014
13-6122 |  | Thomas Guessford vs State of Florida |  | Denied | 07/16/2014
13-6150 |  | Edward Walker vs State of Florida |  | Affirmed | 07/18/2014
13-6206 |  | Collins V. Powers vs State of Florida |  | Denied | 07/24/2014
13-6213 |  | Curtis V. Emanuel vs State of Florida |  | Affirmed | 07/03/2014
13-6237 |  | Travis Walker vs State of Florida |  | Affirmed | 07/21/2014
14-0043 |  | Anthony Holmes vs Comanco Environmental Corp., et al. | corrected 7/14/14 | Affirmed | 07/10/2014
14-0056 |  | Sentry Insurance Company and CGI Technologies etc. vs Karen Sykora |  | Affirmed | 07/17/2014
14-0094 |  | Progressive Employer Management Co. et al. vs Ronald Dulac |  | Affirmed | 07/18/2014
14-0126 |  | Benjamin A. Totten, Former Husband vs Christine M. Totten, Former Wife |  | Affirmed | 07/17/2014
14-0134 |  | John Holland vs State of Florida |  | Affirmed | 07/02/2014
14-0164 |  | Kendrish W. Lissade vs State of Florida |  | Affirmed | 07/02/2014
14-0240 |  | Deonta Shabaz Mills vs State of Florida |  | Affirmed | 07/16/2014
14-0249 |  | Labor Ready Southeast, Inc., et al. vs Foutch Dewane Pittman |  | Affirmed | 07/07/2014
14-0399 |  | Christopher Sanders vs State of Florida |  | Affirmed | 07/24/2014
14-0448 |  | Sawand Palmer vs State of Florida |  | Denied | 07/16/2014
14-0575 |  | Dawn Cheree Brooks vs State of Florida |  | Affirmed | 07/08/2014
14-0593 |  | Dwayne Sercey vs State of Florida |  | Affirmed | 07/23/2014
14-0599 |  | Donnie Demont Phillips vs State of Florida |  | Affirmed | 07/18/2014
14-0604 |  | Richard Michael Novak vs State of Florida |  | Affirmed | 07/03/2014
14-0611 |  | Tracey Dewrell vs Tom Dewrell, Individually and as the etc. |  | Affirmed | 07/16/2014
14-0641 |  | Rodney Newcomb vs Wal-Mart, and Sedgwick |  | Affirmed | 07/16/2014
14-0650 |  | Curtis Robinson vs State of Florida |  | Denied | 07/03/2014
14-0698 |  | Zachery Keith Turner vs State of Florida |  | Denied | 07/18/2014
14-0710 |  | Zeng Jean-Jacques vs State of Florida |  | Denied | 07/16/2014
14-0726 |  | Brian Brown vs Jerry Pybus Electric and North American etc. |  | Affirmed | 07/03/2014
14-0743 |  | John P. McGahen vs State of Florida |  | Affirmed | 07/03/2014
14-0766 |  | Raymond E. Jones vs Department of Corrections |  | Affirmed | 07/21/2014
14-0794 |  | Michael Leslie Carson vs State of Florida |  | Affirmed | 07/03/2014
14-0810 |  | Tommy Green, Sr. vs Michael D. Crews, Secretary, etc. |  | Affirmed | 07/11/2014
14-0819 |  | Erica Nicole Thomas vs State of Florida |  | Denied | 07/24/2014
14-0827 |  | United Parcel Service and Liberty Mutual Ins. Co. vs Steve Aladics |  | Affirmed | 07/16/2014
14-0834 |  | Samantha Willsey vs State of Florida |  | Affirmed | 07/21/2014
14-0850 |  | Steven J. Casker vs State of Florida |  | Denied | 07/16/2014
14-0852 |  | Arianne Myles vs State of Florida |  | Affirmed | 07/16/2014
14-0861 |  | Lawrence Lee Jones vs Florida Department of Corrections |  | Denied | 07/14/2014
14-0923 |  | Aaron S. Burns vs State of Florida |  | Denied | 07/09/2014
14-0944 |  | Bennett K. Tressler, Jr. vs State of Florida |  | Affirmed | 07/03/2014
14-0950 |  | Carol Cunningham vs Reemployment Assistance Appeals Commission et al. |  | Affirmed | 07/18/2014
14-0978 |  | Stacy Lasondo Jackson vs State of Florida |  | Affirmed | 07/03/2014
14-0989 |  | Randall Lee Mays vs State of Florida |  | Affirmed | 07/08/2014
14-1010 |  | Keith Young vs State of Florida |  | Affirmed | 07/17/2014
14-1012 |  | Arron J. Grimes vs State of Florida |  | Affirmed | 07/14/2014
14-1048 |  | Daniel Marion vs State of Florida |  | Affirmed | 07/22/2014
14-1050 |  | Antwann Johnson vs State of Florida |  | Affirmed | 07/07/2014
14-1056 |  | Rick D. Ripple vs State of Florida |  | Affirmed | 07/18/2014
14-1058 |  | Ray James vs Fla. Dept. of Corrections |  | Dismissed | 07/21/2014
14-1068 |  | Ricky Sutton vs State of Florida |  | Affirmed | 07/02/2014
14-1097 |  | Justin Wayne Wood vs State of Florida |  | Affirmed | 07/03/2014
14-1123 |  | Leon D. Smith vs State of Florida |  | Affirmed | 07/02/2014
14-1127 |  | Joseph E. Kenney vs Department of Highway Safety etc. |  | Denied | 07/17/2014
14-1149 |  | Julius S. Davis vs State of Florida |  | Affirmed | 07/23/2014
14-1184 |  | Danny O. Davis vs State of Florida |  | Denied | 07/24/2014
14-1189 |  | Ernest Bellamy vs State of Florida |  | Affirmed | 07/14/2014
14-1191 |  | Keidrick L. Ewing vs State of Florida |  | Affirmed | 07/03/2014
14-1203 |  | Kenneth Bacon vs State of Florida |  | Affirmed | 07/03/2014
14-1208 |  | Antoni Lashawn Knight vs State of Florida |  | Affirmed | 07/03/2014
14-1214 |  | Janard Wright vs State of Florida |  | Affirmed | 07/07/2014
14-1240 |  | Lonnie Fritts vs State of Florida |  | Affirmed | 07/16/2014
14-1266 |  | Carly Brubaker vs Northeast Florida State Hospital |  | Affirmed | 07/03/2014
14-1268 |  | Eddie L. Ash vs State of Florida |  | Affirmed | 07/14/2014
14-1283 |  | Jason Johnson vs State of Florida |  | Affirmed | 07/18/2014
14-1298 |  | Keith Eric Lancaster vs State of Florida |  | Affirmed | 07/03/2014
14-1299 |  | Ronnie Woods vs State of Florida |  | Affirmed | 07/02/2014
14-1301 |  | Randy Spencer vs State of Florida |  | Dismissed | 07/24/2014
14-1315 |  | Willie Owens vs State of Florida |  | Affirmed | 07/09/2014
14-1329 |  | Joseph Benjamin Calloway vs State of Florida |  | Affirmed | 07/03/2014
14-1362 |  | Chanterria Roberts vs State of Florida |  | Affirmed | 07/14/2014
14-1366 |  | Travis McKinney vs State of Florida |  | Affirmed | 07/03/2014
14-1414 |  | Exterior Walls, Inc. vs Construction Materials, Inc, et al. |  | Denied | 07/16/2014
14-1417 |  | Mauricio Kyler vs State of Florida |  | Affirmed | 07/16/2014
14-1423 |  | Allen Lee Williams vs State of Florida |  | Affirmed | 07/03/2014
14-1437 |  | Rockwell Jones vs State of Florida |  | Affirmed | 07/02/2014
14-1442 |  | Calimino Woods, Jr. vs State of Florida |  | Affirmed | 07/03/2014
14-1454 |  | John O. Williams vs State of Florida |  | Affirmed | 07/03/2014
14-1471 |  | Eric Von Easter vs State of Florida |  | Affirmed | 07/07/2014
14-1485 |  | Willie C. Ford, Jr. vs State of Florida |  | Affirmed | 07/23/2014
14-1499 |  | Jessie Lee Davis, II vs State of Florida |  | Affirmed | 07/18/2014
14-1510 |  | William H. Bell vs State of Florida |  | Affirmed | 07/08/2014
14-1514 |  | Bernard Owens vs State of Florida |  | Affirmed | 07/08/2014
14-1528 |  | Danny O. Davis vs State of Florida |  | Affirmed | 07/07/2014
14-1530 |  | Bobbie Laster vs State of Florida |  | Affirmed | 07/07/2014
14-1531 |  | Ian Nigel Nabbs vs State of Florida |  | Denied | 07/03/2014
14-1532 |  | Vernon Jones vs State of Florida |  | Affirmed | 07/03/2014
14-1533 |  | Jermaine T. Holmes vs State of Florida |  | Affirmed | 07/14/2014
14-1536 |  | Omer D. Stokes vs State of Florida |  | Affirmed | 07/16/2014
14-1557 |  | Juan E. Gonzales vs State of Florida |  | Affirmed | 07/03/2014
14-1565 |  | Arthur C. Grace vs State of Florida |  | Affirmed | 07/02/2014
14-1572 |  | William T. Morrison, Jr. vs State of Florida |  | Affirmed | 07/14/2014
14-1591 |  | Anthony Young vs State of Florida |  | Affirmed | 07/07/2014
14-1597 |  | James Garrison vs State of Florida |  | Affirmed | 07/23/2014
14-1602 |  | Theophus Davison vs State of Florida |  | Affirmed | 07/18/2014
14-1646 |  | Jeffrey E. Hobson vs State of Florida |  | Affirmed | 07/02/2014
14-1651 |  | Melvin T. Dixon vs State of Florida |  | Affirmed | 07/03/2014
14-1654 |  | Joseph Wiley vs State of Florida |  | Affirmed | 07/18/2014
14-1670 |  | Billy Comer vs State of Florida |  | Affirmed | 07/03/2014
14-1685 |  | Erick Lorray Armstrong vs State of Florida |  | Affirmed | 07/18/2014
14-1713 |  | Donald S. Verne vs State of Florida |  | Affirmed | 07/17/2014
14-1728 |  | Richard Howard Ramsey vs State of Florida |  | Affirmed | 07/03/2014
14-1757 |  | Reginald Chatman vs State of Florida |  | Affirmed | 07/07/2014
14-1766 |  | Lawrence Baker vs State of Florida |  | Affirmed | 07/23/2014
14-1798 |  | Comer Brascom vs State of Florida |  | Affirmed | 07/03/2014
14-1799 |  | Clinton E. Lewis vs State of Florida |  | Affirmed | 07/03/2014
14-1803 |  | Bill Harley Slaughter vs State of Florida |  | Affirmed | 07/14/2014
14-1829 |  | Bill Harley Slaughter vs State of Florida |  | Affirmed | 07/14/2014
14-1909 |  | Randolph Jackson vs State of Florida |  | Affirmed | 07/16/2014
14-1956 |  | Brian Gallon vs State of Florida |  | Affirmed | 07/03/2014
14-1966 |  | Sherman A. Combs vs State of Florida |  | Affirmed | 07/02/2014
14-1982 |  | Clentis E. Lucuss vs State of Florida |  | Affirmed | 07/10/2014
14-2034 |  | Robert Lowery vs State of Florida |  | Affirmed | 07/03/2014
14-2079 |  | Roddy Kelley vs State of Florida |  | Affirmed | 07/08/2014
14-2122 |  | Antonio Turner vs State of Florida |  | Affirmed | 07/07/2014
14-2126 |  | Mark Anthony Holland vs State of Florida |  | Affirmed | 07/23/2014
14-2141 |  | Auto Truck and Industrial Parts and Supply, etc. vs June B. Miller |  | Dismissed | 07/17/2014
14-2159 |  | Michael Z. Rivera vs State of Florida |  | Affirmed | 07/03/2014
14-2170 |  | Meldon Rich vs State of Florida |  | Affirmed | 07/02/2014
14-2202 |  | Ralph Ross vs State of Florida |  | Denied | 07/03/2014
14-2328 |  | Causseaux, Hewett & Walpole, Inc. etc. vs Hopewell, LLC |  | Denied | 07/03/2014
14-2340 |  | Thomas Kahlow vs Florida Parole Commission |  | Dismissed | 07/09/2014
14-2358 |  | Lorenzo Howard vs Michael D. Crews, Secretary, etc. et al. |  | Denied | 07/16/2014
14-2371 |  | Sterling Robert Owens vs State of Florida |  | Affirmed | 07/02/2014
14-2406 |  | Johnny Welch vs State of Florida |  | Denied | 07/09/2014
14-2422 |  | Kennedy Wright vs Department of Corrections |  | Dismissed | 07/17/2014
14-2423 |  | Marzuq Al-Hakim vs State of Florida |  | Denied | 07/03/2014
14-2443 |  | Anthony Graham vs State of Florida |  | Denied | 07/09/2014
14-2549 |  | Barrington E. Morais vs State of Florida |  | Denied | 07/09/2014
14-2552 |  | Charles Francis vs State of Florida |  | Denied | 07/16/2014
14-2560 |  | John H. Cirota vs State of Florida |  | Denied | 07/03/2014
14-2589 |  | Ioannis Papadopoulos vs Reemployment Assistance Appeals Commission, et al |  | Dismissed | 07/09/2014
14-2709 |  | Bill Harley Slaughter vs Michael D. Crews, Secretary, etc. et al. |  | Denied | 07/03/2014
14-2716 |  | Charles C. Sanmann vs State of Florida |  | Denied | 07/24/2014
14-2785 |  | Jerry Lee Nichols vs State of Florida |  | Dismissed | 07/03/2014
14-2790 |  | Lucious Jackson vs State of Florida |  | Denied | 07/09/2014
14-2871 |  | Malachi Smith vs State of Florida |  | Denied | 07/24/2014
14-2883 |  | James Richard Bain vs State of Florida |  | Denied | 07/09/2014
14-2927 |  | Florida Wildlife Federation, Inc. vs Department of Environmental Protection |  | Dismissed | 07/24/2014
14-2934 |  | Harens Aleydi Erazo vs State of Florida |  | Denied | 07/24/2014
14-2937 |  | Ronald Nelson Brown vs State of Florida |  | Denied | 07/16/2014
14-2940 |  | Weston Jackson vs State of Florida |  | Denied | 07/24/2014
14-2943 |  | Willie James Hunter vs State of Florida |  | Denied | 07/16/2014